@@ -46,10 +46,12 @@ NOSDTimeDateCtl::~NOSDTimeDateCtl()
 QString NOSDTimeDateCtl::timeZone() const
 {
     QFile tzFile(QSL("/etc/timezone"));
-         if (!tzFile.open(QFile::ReadOnly | QFile::Text)) return QSL("Unknown");
-         QTextStream in(&tzFile);
-             QString lastTZone = in.readLine();
-                 return lastTZone;
+    if (!tzFile.open(QFile::ReadOnly | QFile::Text))
+        return QSL("Unknown");
+
+    QTextStream in(&tzFile);
+    QString lastTZone = in.readLine();
+    return lastTZone;
 }
 
 bool NOSDTimeDateCtl::setTimeZone(QString timeZone, QString& /*errorMessage*/)
@@ -99,18 +101,19 @@ bool NOSDTimeDateCtl::localRtc() const
 {
     QFile tzFile(QSL("/etc/sysconfig/clock"));
     if (!tzFile.open(QFile::ReadOnly | QFile::Text))
-	return false;
+        return false;
+
     QTextStream in(&tzFile);
     QString all = in.readAll();
     QStringList sl = all.split(QSL("\n"));
-    for (QStringList::iterator it = sl.begin(); it != sl.end(); it++) {
-	QString current = *it;
-	if(current.startsWith(QSL("#")))
-	    continue;
-	if(current.startsWith(QSL("UTC=1")) || current.startsWith(QSL("UTC=true")))
-            return false;
-	if(current.startsWith(QSL("UTC=0")) || current.startsWith(QSL("UTC=false")))
-            return true;
+    for (QStringList::iterator it = sl.begin(); it != sl.end(); ++it) {
+        QString current = *it;
+        if(current.startsWith(QSL("#")))
+            continue;
+        if(current.startsWith(QSL("UTC=1")) || current.startsWith(QSL("UTC=true")))
+                return false;
+        if(current.startsWith(QSL("UTC=0")) || current.startsWith(QSL("UTC=false")))
+                return true;
     }
     return false;
 }
